@@ -197,8 +197,7 @@ class BaseServer(object):
                 function_name, 
                 uuid,
                 error))
-        # return error
-        return
+        return error
 
     def _callExposedFunctionCallback(self, data, function_name, uuid):
         LOGGER.debug("Function %s returned successfully." % (function_name))
